API docs for “spamfighter.core.commands.test.test_serialize”

# Module s.c.c.t.test_serialize

Part of spamfighter.core.commands.test View Source

Тесты на `spamfighter.core.commands.serialize`.

Class | INotSerializableInterface | Undocumented
Class | ISerializableInterface | Undocumented
Class | SerializabeClass | Undocumented
Class | RegisterTestCase | Тесты на `spamfighter.core.commands.serialize.register_serializer`, `spamfighter.core.commands.serialize.get_serializer`.
Class | DateTimeTestCase | Тесты на `spamfighter.core.commands.serialize.DateTime`.